TraceRouter

Struct TraceRouter 

pub struct TraceRouter { /* private fields */ }
Pub-sub router for trace data

Implementations

Source

impl TraceRouter

pub fn new( cancellation_token: CancellationToken, ) -> (Arc<Self>, impl Future<Output = Result<()>>)

Create a new trace router with the default metadata-only store

pub fn new_with_store( store: Arc<dyn Store>, cancellation_token: CancellationToken, ) -> (Arc<Self>, impl Future<Output = Result<()>>)

Create a new trace router with a specific store implementation

pub fn sender(&self) -> Sender

pub async fn subscribe_all_blocking( &self, ) -> Result<(Receiver, Vec<IpcMessageWithId>)>

Subscribe to all data, applying backpressure when needed

pub async fn subscribe( &self, ) -> Result<(TraceSink, Receiver, Vec<IpcMessageWithId>)>

Subscribe to trace streams

pub async fn subscribe_all_blocking_stream( &self, ) -> Result<impl Stream<Item = IpcMessageWithId> + use<>>

pub async fn subscribe_stream( &self, ) -> Result<(TraceSink, impl Stream<Item = IpcMessageWithId> + use<>)>