pub struct TraceSink { /* private fields */ }Expand description
A trace sink is a client connection for the trace router. It hold state about what data the client has seen and is subscribed to.
Implementations