EventBuilder

Struct EventBuilder 

pub struct EventBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> EventBuilder<'a>

pub fn emit(self) -> Result<()>

Emit the event at the current time.

pub fn emit_at(self, time_ns: i64) -> Result<()>

Emit the event at a specific time.

pub async fn emit_async(self) -> Result<()>

Emit the event at the current time via async

pub async fn emit_at_async(self, time_ns: i64) -> Result<()>

Emit the event at a specific time via async

pub fn try_insert(&mut self, name: &str, value: Value) -> Result<()>

Attempt to insert a value into the event, returning an error if the field is not found or the type does not match.

pub fn try_insert_i8(self, name: &str, value: i8) -> Result<Self>

pub fn try_insert_i16(self, name: &str, value: i16) -> Result<Self>

pub fn try_insert_i32(self, name: &str, value: i32) -> Result<Self>

pub fn try_insert_i64(self, name: &str, value: i64) -> Result<Self>

pub fn try_insert_u8(self, name: &str, value: u8) -> Result<Self>

pub fn try_insert_u16(self, name: &str, value: u16) -> Result<Self>

pub fn try_insert_u32(self, name: &str, value: u32) -> Result<Self>

pub fn try_insert_u64(self, name: &str, value: u64) -> Result<Self>

pub fn try_insert_f32(self, name: &str, value: f32) -> Result<Self>

pub fn try_insert_f64(self, name: &str, value: f64) -> Result<Self>

pub fn try_insert_timestamp_ns(self, name: &str, value: i64) -> Result<Self>

pub fn try_insert_binary(self, name: &str, value: Vec<u8>) -> Result<Self>

pub fn try_insert_string(self, name: &str, value: String) -> Result<Self>

pub fn try_insert_bool(self, name: &str, value: bool) -> Result<Self>