pub struct TraceSourceEvent {
pub name: String,
pub schema: Vec<TraceEventFieldMetadata>,
/* private fields */
}Expand description
TraceSourceEvent is a child of a TraceSource, which contains the schema for the event, as well as helpers for building and emitting new events for that schema.
Fields
name: Stringschema: Vec<TraceEventFieldMetadata>Implementations