Modules
Structs
- Trace
Source - TraceSource is the main interface to emitting Zelos trace events. It provides convencience methods for building new event schemas and emitting events from them.
- Trace
Source Event - TraceSourceEvent is a child of a TraceSource, which contains the schema for the event, as well as helpers for building and emitting new events for that schema.